'''`bestdori.ayachan.exceptions`

ayachan API 错误信息相关操作'''
from typing import Any

# 错误基类
class BaseException(Exception):
    '''错误基类'''
    # 初始化
    def __init__(self, msg: str) -> None:
        self.message = msg
        '''错误信息'''
    
    # 字符串化
    def __str__(self) -> str:
        '''输出字符串'''
        return self.message

# Sonolus 相关错误
class SonolusException(BaseException):
    '''Sonolus 相关错误'''
    # 初始化
    def __init__(self, msg: str) -> None:
        super().__init__(msg)




from utils.note import BPM as BPM
from utils.note import Slide as Slide
from utils.note import Single as Single
from utils.note import NoteType as NoteType
from utils.note import Connection as Connection
from utils.note import Directional as Directional

from utils.content import Br as Br
from utils.content import Link as Link
from utils.content import List as List
from utils.content import Text as Text
from utils.content import Emoji as Emoji
from utils.content import Image as Image
from utils.content import Content as Content
from utils.content import Heading as Heading
from utils.content import Mention as Mention
